geotargets: 'targets' Extensions for Geographic Spatial Formats
Source:R/geotargets-package.R
geotargets-package.RdProvides extensions for various geographic spatial file formats, such as shape files and rasters. Currently provides support for the 'terra' geographic spatial formats. See the vignettes for worked examples, demonstrations, and explanations of how to use the various package extensions.